---
sidebar_position: 1
---

# Getting Started

BondAI comes with a build in RESTful and WebSocket API server. You can start this server using the CLI by specifying the `--server` argument. If no port number is specified, by default the server will run on port 2663.
```
bondai --server [PORT]
```
